import glob
import os
import sys

APP_NAME = 'pyscrabble'

def get_app_data_dir():
    '''
    Get application specific data dir
    
    @return: Application data directory
    '''
    if sys.platform == 'win32':
        try:
            from win32com.shell.shell import SHGetFolderPath
            from win32com.shell.shellcon import CSIDL_APPDATA, CSIDL_COMMON_APPDATA
            app_data_dir = SHGetFolderPath(0, CSIDL_APPDATA, 0, 0)
            if not os.path.exists(app_data_dir):
                app_data_dir = SHGetFolderPath(0, CSIDL_COMMON_APPDATA, 0, 0)
        except ImportError, inst:
            app_data_dir = 'C:\\'
        return os.path.join(app_data_dir, APP_NAME)
    else:
        return os.path.join(os.path.expanduser('~'), '.config',  APP_NAME)

try:
    from __installed__ import RESOURCE_PREFIX
except ImportError:
    RESOURCE_PREFIX = 'resources'

CONFIG_DIR = get_app_data_dir()

try:
    from __installed__ import SERVER_LOG_DIR, SERVER_DB_DIR, SERVER_CONFIG_DIR
except ImportError:
    SERVER_CONFIG_DIR = os.path.join(RESOURCE_PREFIX, 'config')
    SERVER_DB_DIR = CONFIG_DIR
    SERVER_LOG_DIR = CONFIG_DIR

def ensure_config_dir(dir):
    '''
    Ensure config directory exists
    
    @param dir: Dir
    '''
    if not os.path.exists(dir):
        os.makedirs(dir)


class Resource(object):
    '''
    Filesystem resource
    '''
    
    def __init__(self, path=None):
        '''
        Constructor
        
        @param path: Resource path
        '''
        
        self.data = {}
        if path is not None:
            self.path = os.path.abspath(path)
            
            if os.path.isdir( self.path ):
                self.addSubResources()
    
    def addSubResources(self):
        '''
        Add sub resources
        '''
        for item in os.listdir( self.path ):
            r = os.path.join(self.path, item)
            if os.path.isdir(r):
                r = Resource(r)
            self[item] = r
    
    def __repr__(self):
        '''
        @return: Path
        '''
        return self.path
        
    def __getitem__(self, item):
        '''
        Get item
        
        @param item: Item
        @return: Resource item
        '''
        try:
            return self.data[item]
        except KeyError:
            return os.path.join(self.path, item)
    
    def __setitem__(self, item, value):
        '''
        Set item
        
        @param item:
        @param value:
        '''
        self.data[item] = value
        